@@ -34,12 +34,12 @@ def random_sampler(df,variable,plot=False):
 #3
 def mean_imputation(df,variable,plot=False):
 	mean=df[variable].mean()
-	df[variable+"_mean"]=df[variable].fillna(mean).inplace=True
+	df[variable+"_mean"]=df[variable].fillna(mean)
 	if plot==True:
 		sns.kdeplot(df[variable+"_mean"])
 		sns.kdeplot(df[variable])
 	df[variable]=df[variable+"_mean"]
-    df=df.drop([variable+"_mean"],axis=1,inplace=True)
+	df=df.drop([variable+"_mean"],axis=1,inplace=True)
 
 
 
@@ -47,12 +47,12 @@ def mean_imputation(df,variable,plot=False):
 #4
 def mode_imputation(df,variable,plot=False):
 	mode=df[variable].mode()
-	df[variable+"_mode"]=df[variable].fillna(mode).inplace=True
+	df[variable+"_mode"]=df[variable].fillna(mode)
 	if plot==True:
 		sns.kdeplot(df[variable+"_mode"])
 		sns.kdeplot(df[variable])
 	df[variable]=df[variable+"_mode"]
-    df=df.drop([variable+"_mode"],axis=1,inplace=True)
+	df=df.drop([variable+"_mode"],axis=1,inplace=True)
 
 
 
@@ -74,7 +74,7 @@ def endof_distribution(df,variable,plot=False):
 		sns.kdeplot(df[variable+"_enddist"])
 		sns.kdeplot(df[variable])
 	df[variable]=df[variable+"_enddist"]
-    df=df.drop([variable+"_enddist"],axis=1,inplace=True)
+	df=df.drop([variable+"_enddist"],axis=1,inplace=True)
 
 
 
@@ -86,7 +86,7 @@ def arbitrary_imputation(df,variable,arbit,plot=False):
 		sns.kdeplot(df[variable+"_arbitrary"])
 		sns.kdeplot(df[variable])
 	df[variable]=df[variable+"_arbitrary"]
-    df=df.drop([variable+"_arbitrary"],axis=1,inplace=True)
+	df=df.drop([variable+"_arbitrary"],axis=1,inplace=True)
 
 
 
